==> licenses-generator-1.0.0-sources.jar: me/snowdrop/licenses/sanitiser/ExceptionLicenseSanitiser.java <==
/*
 * Copyright 2016-2017 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.snowdrop.licenses.sanitiser;

import java.util.Set;

import me.snowdrop.licenses.utils.JsonUtils;
import me.snowdrop.licenses.xml.DependencyElement;

/**
 * @author <a href="mailto:gytis@redhat.com">Gytis Trikleris</a>
 */
public class ExceptionLicenseSanitiser implements LicenseSanitiser {

    private final Set<DependencyElement> exceptions;

    private final LicenseSanitiser next;

    public ExceptionLicenseSanitiser(String exceptionsFilePath, LicenseSanitiser next) {
        this.exceptions = JsonUtils.loadJsonToSet(exceptionsFilePath, DependencyElement::new);
        this.next = next;
    }

    @Override
    public DependencyElement fix(DependencyElement dependencyElement) {
        return exceptions.stream()
                .filter(dependencyElement::equals)
                .findFirst()
                .map(DependencyElement::new)
                .orElseGet(() -> next.fix(dependencyElement));

    }

}

==> licenses-generator-1.2.0-sources.jar: me/snowdrop/licenses/sanitiser/ExceptionLicenseSanitiser.java <==
/*
 * Copyright 2016-2017 Red Hat, Inc, and individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.snowdrop.licenses.sanitiser;

import java.util.Set;

import me.snowdrop.licenses.sanitiser.exceptions.LicenseException;
import me.snowdrop.licenses.utils.JsonUtils;
import me.snowdrop.licenses.xml.DependencyElement;

/**
 * @author <a href="mailto:gytis@redhat.com">Gytis Trikleris</a>
 */
public class ExceptionLicenseSanitiser implements LicenseSanitiser {

    private final Set<LicenseException> exceptions;

    private final LicenseSanitiser next;

    public ExceptionLicenseSanitiser(String exceptionsFilePath, LicenseSanitiser next) {
        this.exceptions = JsonUtils.loadJsonToSet(exceptionsFilePath, LicenseException::new);
        this.next = next;
    }

    @Override
    public DependencyElement fix(DependencyElement dependencyElement) {
        return exceptions.stream()
                .filter(exception -> exception.matches(dependencyElement))
                .findFirst()
                .map(exception -> new DependencyElement(dependencyElement, exception.getLicenses()))
                .orElseGet(() -> next.fix(dependencyElement));

    }

}
